[PATCH] lib: consider all instances of Delivered-To header

Subject: [PATCH] lib: consider all instances of Delivered-To header

Date: Wed, 23 Jun 2021 13:29:06 +0300

To: notmuch@notmuchmail.org

Cc: Hannu Hartikainen

From: Hannu Hartikainen


When using notmuch-reply and guessing the From: address from
Delivered-To headers, I had the wrong address chosen today. This was
because the messages from the notmuch list contain these headers in this
order:

Delivered-To: hannu.hartikainen@gmail.com
...
Delivered-To: hannu@hrtk.in

In my .notmuch-config I have the following configuration:

primary_email=hannu@hrtk.in
other_email=hannu.hartikainen@gmail.com;...

Before this change, notmuch-reply would guess From: @gmail.com because
that is the first Delivered-To header present. After the change, the
primary address is chosen as I would expect.
---
 lib/message-file.c | 12 ++++++++----
 1 file changed, 8 insertions(+), 4 deletions(-)

diff --git a/lib/message-file.c b/lib/message-file.c
index 647ccf3a..7e8ea09c 100644
--- a/lib/message-file.c
+++ b/lib/message-file.c
@@ -291,11 +291,15 @@ _notmuch_message_file_get_header (notmuch_message_file_t *message,
     if (value)
 	return value;
 
-    if (strcasecmp (header, "received") == 0) {
+    if (strcasecmp (header, "received") == 0 ||
+            strcasecmp (header, "delivered-to") == 0) {
 	/*
 	 * The Received: header is special. We concatenate all
 	 * instances of the header as we use this when analyzing the
 	 * path the mail has taken from sender to recipient.
 	 */
 	decoded = _notmuch_message_file_get_combined_header (message, header);
     } else {
@@ -291,11 +291,15 @@ _notmuch_message_file_get_header (notmuch_message_file_t *message,
 	/*
-	 * The Received: header is special. We concatenate all
-	 * instances of the header as we use this when analyzing the
-	 * path the mail has taken from sender to recipient.
+	 * The Received: header is special. We concatenate all instances of the
+	 * header as we use this when analyzing the path the mail has taken
+	 * from sender to recipient.
+	 *
+	 * Similarly, multiple instances of Delivered-To may be present. We
+	 * concatenate them so the one with highest priority may be picked.
 	 */
 	decoded = _notmuch_message_file_get_combined_header (message, header);
-- 
2.32.0
_______________________________________________
notmuch mailing list -- notmuch@notmuchmail.org
To unsubscribe send an email to notmuch-leave@notmuchmail.org

Thread: